@@ -4,10 +4,11 @@ from json import JSONDecodeError
 from pathlib import Path
 
 import click
-import defektor_api
 from defektor_api import Configuration
 from jsonschema import validate, ValidationError
 from python_jsonschema_objects import ObjectBuilder
+from defektor_api.apis import DefaultApi
+from defektor_api import ApiClient
 
 from dfk.cli import DfkCli
 
@@ -68,5 +69,5 @@ def require_login(func):
         click.echo("ERROR: Please login!\n$ dfk login")
         exit(1)
 
-    api_client = defektor_api.ApiClient(get_config())
-    DfkCli.api_instance = defektor_api.DefaultApi(api_client)
+    api_client = ApiClient(get_config())
+    DfkCli.api_instance = DefaultApi(api_client)
